==> alexachatbot-0.0.1.tar.gz: alexachatbot-0.0.1/README.md <==
# Alexa Chatbot

## Genrale Information

Alexa chatbot is a simple  python pakcage for createing chatbot in python, it's help you to create a basic chatbot




[github](https://github.com/A-l-t-e-r-o/Alexa-chatbot)

## Installation
---
```python
pip install alexachatbot
```

First you need to install alexa-chatbot from pypi it's open-source and completelly free




## Features
---
- Lightweight and Fast
- Supoort mutiples language
- Easy to use




## Usage
---

Here is a simple Exampel how can you user Alexa-chatbot

### reply() | function

---
```python
from alexa_chatbot.alexaAI import reply
text = "How are you?"
res = reply(text)
print(res)
# do further things what you want to do with res
```

> Note: text pateamter are require and it should be string
> It's Supoort mutiples language so you can pass any kind of message and you will get a good reply

#### Other example of reaply function
```python
from alexa_chatbot.alexaAI import reply
text = "こん に ち わ"
res = reply(text)
print(res)
# same as do further things what you want to do with res
```


### replylang() | function
---

```python
from alexa_chatbot.alexaAI import replylang
text = "what are you doing right now?"
lang = 'en'
res = replylang(text,lang)
print(res)
# same as do further things what you want to do with res
```
> Note: text and lang both pateamter are require and it should be string
> It's Supoort mutiples language so you can pass any kind of message and you will get a good reply







> Note: `Alexa-chatbot using a api, but sometimes api go down so don't worry and wait a little bit` 

## License
---
Alexa-chatbot is released under MIT License, See License for more detalis

## Contect 
---

[Sololearn](https://www.sololearn.com/Profile/20092467/?ref=app)
[Discosrd server](https://discord.gg/9HeumuBCbV)
[Telegram](https://t.me/joinchat/OC_bVbchsz8zMjY1)
[youtube](https://www.youtube.com/channel/UCEY672gqkUt-EdFuAXRQtLQ)
[git-hub](https://www.sololearn.com/Profile/20092467/?ref=app)
[Gamil](alteromiiller@gmail.com)

==> alexachatbot-0.0.2.tar.gz: alexachatbot-0.0.2/README.md <==
# Alexa Chatbot

## Genrale Information

Alexa chatbot is a simple  python pakcage for createing chatbot in python, it's help you to create a basic chatbot




[github](https://github.com/A-l-t-e-r-o/Alexa-chatbot)

## Installation
---
```python
pip install alexachatbot
```

First you need to install alexa-chatbot from pypi it's open-source and completelly free




## Features
---
- Lightweight and Fast
- Supoort mutiples language
- Easy to use




## Usage
---

Here is a simple Exampel how can you user Alexa-chatbot

### reply() | function

---
```python
from alexachatbot.alexaAI import reply
text = "How are you?"
res = reply(text)
print(res)
# do further things what you want to do with res
```

> Note: text pateamter are require and it should be string
> It's Supoort mutiples language so you can pass any kind of message and you will get a good reply

#### Other example of reaply function
```python
from alexachatbot.alexaAI import reply
text = "こん に ち わ"
res = reply(text)
print(res)
# same as do further things what you want to do with res
```


### replylang() | function
---

```python
from alexachatbot.alexaAI import replylang
text = "what are you doing right now?"
lang = 'en'
res = replylang(text,lang)
print(res)
# same as do further things what you want to do with res
```
> Note: text and lang both pateamter are require and it should be string
> It's Supoort mutiples language so you can pass any kind of message and you will get a good reply







> Note: `Alexa chatbot using a api, but sometimes api go down so don't worry and wait a little bit` 

## License
---
Alexa chatbot is released under MIT License, See License for more detalis

## Contect 
---

[Sololearn](https://www.sololearn.com/Profile/20092467/?ref=app)
[Discosrd server](https://discord.gg/9HeumuBCbV)
[Telegram](https://t.me/joinchat/OC_bVbchsz8zMjY1)
[youtube](https://www.youtube.com/channel/UCEY672gqkUt-EdFuAXRQtLQ)
[git-hub](https://www.sololearn.com/Profile/20092467/?ref=app)
[Gamil](alteromiiller@gmail.com)
